@@ -1,10 +1,10 @@
 import keras
 from tensorflow.keras.callbacks import LambdaCallback
-import topicmodels.eval_measure
-from topicmodels.corpus import DocData,DocDatalstm
-import topicmodels.ldann
-from topicmodels.ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
-from topicmodels.eval_measure import custom_evaluator
+import eval_measure
+from corpus import DocData,DocDatalstm
+import ldann
+from ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
+from eval_measure import custom_evaluator
 import os
 import collections
 import numpy as np
@@ -52,9 +52,10 @@ def word_frq(str):
     return tmpsum
 
 
-def topicmodelingtransformer(dataset,no_topic,topic_word,column_name='clean_tweet'):
-    modelweights_path=os.environ['FAST_TEXT_MODEL_PATH']
-    print("starting transformer model with model path:",modelweights_path)
+def topicmodelingtransformer(dataset,no_topic,topic_word,weight_dir,column_name='clean_tweet'):
+#     modelweights_path="C:/Users/SANJEEV/Desktop/complete code 13feb/fasttext10.bin"
+    modelweights_path=weight_dir
+    print("starting transformer model")
     num_topic=no_topic
     topic_num=int(num_topic)
     word_num=int(topic_word)
